@@ -3,13 +3,14 @@ use v5.14;
 use warnings;
 use utf8;
 
-our $VERSION = "0.03";
+our $VERSION = "0.04";
 
 use Data::Dumper;
-use List::Util qw(shuffle);
+use List::Util qw(shuffle min max);
 use Date::Calc qw(Delta_Days);
 use charnames ':full';
 use Getopt::EX::Colormap qw(colorize ansi_code);
+use Text::VisualWidth::PP 0.05 'vwidth';
 use App::Greple::wordle::word_all    qw(%word_all);
 use App::Greple::wordle::word_hidden qw(@word_hidden);
 use App::Greple::wordle::hint qw(&keymap);
@@ -27,7 +28,10 @@ our %opt = ( answer  => \( our $answer      = $ENV{WORDLE_ANSWER} ),
 my @answers;
 
 sub respond {
-    print ansi_code("{CUU}{CUF(8)}");
+    local $_ = $_;
+    my $chomped = chomp;
+    print ansi_code("{CHA}{CUU}") if $chomped;
+    print ansi_code(sprintf("{CHA}{CUF(%d)}", max(8, vwidth($_) + 2)));
     print s/(?<=.)\z/\n/r for @_;
 }
 
@@ -72,28 +76,28 @@ sub show_answer {
 }
 
 sub check {
-    chomp;
-    if (not $word_all{lc $_}) {
+    my $it = lc s/\n//r;
+    if (not $word_all{$it}) {
 	respond $msg_wrong;
 	$_ = '';
     } else {
-	push @answers, $_;
-	$try--;
+	push @answers, $it;
+	print ansi_code '{CUU}';
     }
 }
 
 sub inspect {
-    if (lc $_ eq $answer) {
-	respond $msg_correct;
+    my $it = lc s/\n//r;
+    if (lc $it eq lc $answer) {
+	respond $msg_correct x $try;
 	exit 0;
     }
-    if ($try <= 0) {
+    length or return;
+    if (--$try <= 0) {
 	show_answer;
 	exit 1;
     }
-    if (length and $keymap) {
-	respond keymap($answer, @answers);
-    }
+    $keymap and respond keymap($answer, @answers);
 }
 
 1;
