@@ -13,7 +13,7 @@ my %cmap = (
     G => '555/#6aaa64',
     Y => '555/#c9b458',
     K => '#787c7e/#787c7e',
-    _ => '',
+    _ => '555/#787c7e',
     );
 
 sub keymap {
